from . import download
download.downloading()


bl_info = {
    "name": "Instant Clean",
    "description": "The Ultimate Mesh Clean",
    "blender": (2, 93, 0),
    "version": ("2.2.0",),
    "category": "Mesh",
    "author": "Ruben Messerschmidt",
    "location": "View3D > Sidebar > Instant Clean",
    "doc_url": "https://go.rubenmesserschmidt.com/ToS8vi",
    "version_url": "https://raw.githubusercontent.com/rubenmesserschmidt/Instant-Clean_docs/main/version",
}

addon_id = "instantclean"

import os

import bpy

from . import auto_load
from . import icons
from . import props
from . import ui

from . import handlers
from .utils import operators
from .utils import presets
from .utils import system
from .utils import addon
from . import translate


MODULES = [
    auto_load,
    icons,
    props,
    ui,
    handlers,
]


if bpy.app.version < bl_info["blender"]:
    raise Exception(
        f"{bl_info['name']} requires Blender {bl_info['blender']} or higher!"
        f"\nPlease update Blender to the latest version."
    )
else:
    auto_load.init()

    def register():
        for module in MODULES:
            module.register()

        # check for missing modules
        if not addon.is_extension():
            required_modules = system.get_required_modules()
            if system.get_missing_modules(required_modules):
                bpy.app.timers.register(
                    lambda: operators.invoke_in_area(
                        f"{addon_id}.requirements_installer", "PREFERENCES"
                    ),
                    first_interval=0.1,
                )

        # TODO: uncomment if blender market supports extensions
        # invoke update popup if not extension
        # if not addon.is_extension():
        bpy.app.timers.register(
            lambda: operators.invoke_in_area(f"{addon_id}.update_check", "PREFERENCES"),
            first_interval=0.1,
        )

        # install presets if not already
        presets_path = os.path.join(
            bpy.utils.user_resource("SCRIPTS", path="presets", create=True),
            "Instant Clean",
        )
        if not os.path.isdir(presets_path):
            presets.install_presets()
        translate.register()
    def unregister():
        for module in reversed(MODULES):
            module.unregister()
        translate.unregister()
